@@ -30,18 +30,15 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"""
-|UDM| module for all mail objects
-"""
+"""|UDM| module for all mail objects"""
 
-from univention.admin.layout import Tab
 import univention.admin.filter
-import univention.admin.localization
-
 import univention.admin.handlers
 import univention.admin.handlers.mail.domain
 import univention.admin.handlers.mail.folder
 import univention.admin.handlers.mail.lists
+import univention.admin.localization
+from univention.admin.layout import Tab
 
 
 translation = univention.admin.localization.translation('univention.admin.handlers.mail')
@@ -60,14 +57,14 @@ childmodules = ["mail/folder", "mail/domain", "mail/lists"]
 virtual = True
 options = {}
 property_descriptions = {
-	'name': univention.admin.property(
-		short_description=_('Name'),
-		long_description='',
-		syntax=univention.admin.syntax.string,
-		include_in_default_search=True,
-		required=True,
-		identifies=True
-	),
+    'name': univention.admin.property(
+        short_description=_('Name'),
+        long_description='',
+        syntax=univention.admin.syntax.string,
+        include_in_default_search=True,
+        required=True,
+        identifies=True,
+    ),
 }
 layout = [Tab(_('General'), _('Basic settings'), ["name"])]
 
@@ -75,16 +72,16 @@ mapping = univention.admin.mapping.mapping()
 
 
 class object(univention.admin.handlers.simpleLdap):
-	module = module
+    module = module
 
 
 def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
-	ret = []
-	ret += univention.admin.handlers.mail.domain.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-	ret += univention.admin.handlers.mail.folder.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-	ret += univention.admin.handlers.mail.lists.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
-	return ret
+    ret = []
+    ret += univention.admin.handlers.mail.domain.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
+    ret += univention.admin.handlers.mail.folder.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
+    ret += univention.admin.handlers.mail.lists.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
+    return ret
 
 
 def identify(dn, attr, canonical=False):
-	pass
+    pass
