@@ -30,31 +30,28 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"""
-|UDM| module for the admin container policies
-"""
+"""|UDM| module for the admin container policies"""
 
-from univention.admin.layout import Tab, Group
-import univention.admin.syntax
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
-
+import univention.admin.syntax
+from univention.admin.layout import Group, Tab
 from univention.admin.policy import (
-	register_policy_mapping, policy_object_tab,
-	requiredObjectClassesProperty, prohibitedObjectClassesProperty,
-	fixedAttributesProperty, emptyAttributesProperty, ldapFilterProperty
+    emptyAttributesProperty, fixedAttributesProperty, ldapFilterProperty, policy_object_tab,
+    prohibitedObjectClassesProperty, register_policy_mapping, requiredObjectClassesProperty,
 )
 
+
 translation = univention.admin.localization.translation('univention.admin.handlers.policies')
 _ = translation.translate
 
 
 class adminFixedAttributes(univention.admin.syntax.select):
-	name = 'adminFixedAttributes'
-	choices = [
-		('univentionAdminListModules', _('List of Univention Directory Manager modules')),
-	]
+    name = 'adminFixedAttributes'
+    choices = [
+        ('univentionAdminListModules', _('List of Univention Directory Manager modules')),
+    ]
 
 
 module = 'policies/admin_container'
@@ -71,45 +68,45 @@ object_name_plural = _('Univention Directory Manager container settings policies
 policy_short_description = _('Univention Directory Manager container settings')
 long_description = ''
 options = {
-	'default': univention.admin.option(
-		short_description=short_description,
-		default=True,
-		objectClasses=['top', 'univentionPolicy', 'univentionPolicyAdminContainerSettings'],
-	),
+    'default': univention.admin.option(
+        short_description=short_description,
+        default=True,
+        objectClasses=['top', 'univentionPolicy', 'univentionPolicyAdminContainerSettings'],
+    ),
 }
 property_descriptions = {
-	'name': univention.admin.property(
-		short_description=_('Name'),
-		long_description='',
-		syntax=univention.admin.syntax.policyName,
-		include_in_default_search=True,
-		required=True,
-		may_change=False,
-		identifies=True,
-	),
-	'listModules': univention.admin.property(
-		short_description=_('Available Univention Directory Manager modules'),
-		long_description='',
-		syntax=univention.admin.syntax.univentionAdminModules,
-		multivalue=True,
-	),
+    'name': univention.admin.property(
+        short_description=_('Name'),
+        long_description='',
+        syntax=univention.admin.syntax.policyName,
+        include_in_default_search=True,
+        required=True,
+        may_change=False,
+        identifies=True,
+    ),
+    'listModules': univention.admin.property(
+        short_description=_('Available Univention Directory Manager modules'),
+        long_description='',
+        syntax=univention.admin.syntax.univentionAdminModules,
+        multivalue=True,
+    ),
 }
 property_descriptions.update(dict([
-	requiredObjectClassesProperty(),
-	prohibitedObjectClassesProperty(),
-	fixedAttributesProperty(syntax=adminFixedAttributes),
-	emptyAttributesProperty(syntax=adminFixedAttributes),
-	ldapFilterProperty(),
+    requiredObjectClassesProperty(),
+    prohibitedObjectClassesProperty(),
+    fixedAttributesProperty(syntax=adminFixedAttributes),
+    emptyAttributesProperty(syntax=adminFixedAttributes),
+    ldapFilterProperty(),
 ]))
 
 layout = [
-	Tab(_('General'), _('Univention Directory Manager settings'), layout=[
-		Group(_('General Univention Directory Manager container settings'), layout=[
-			'name',
-			'listModules',
-		]),
-	]),
-	policy_object_tab(),
+    Tab(_('General'), _('Univention Directory Manager settings'), layout=[
+        Group(_('General Univention Directory Manager container settings'), layout=[
+            'name',
+            'listModules',
+        ]),
+    ]),
+    policy_object_tab(),
 ]
 
 mapping = univention.admin.mapping.mapping()
@@ -119,7 +116,7 @@ register_policy_mapping(mapping)
 
 
 class object(univention.admin.handlers.simplePolicy):
-	module = module
+    module = module
 
 
 lookup = object.lookup
