@@ -30,20 +30,16 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"""
-|UDM| module for |DHCP| netbios setting policies
-"""
+"""|UDM| module for |DHCP| netbios setting policies"""
 
-from univention.admin.layout import Tab, Group
-import univention.admin.syntax
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
-
+import univention.admin.syntax
+from univention.admin.layout import Group, Tab
 from univention.admin.policy import (
-	register_policy_mapping, policy_object_tab,
-	requiredObjectClassesProperty, prohibitedObjectClassesProperty,
-	fixedAttributesProperty, emptyAttributesProperty, ldapFilterProperty
+    emptyAttributesProperty, fixedAttributesProperty, ldapFilterProperty, policy_object_tab,
+    prohibitedObjectClassesProperty, register_policy_mapping, requiredObjectClassesProperty,
 )
 
 
@@ -52,12 +48,12 @@ _ = translation.translate
 
 
 class dhcp_netbiosFixedAttributes(univention.admin.syntax.select):
-	name = 'dhcp_netbiosFixedAttributes'
-	choices = [
-		('univentionDhcpNetbiosNameServers', _('NetBIOS name servers')),
-		('univentionDhcpNetbiosScope', _('NetBIOS scope')),
-		('univentionDhcpNetbiosNodeType', _('NetBIOS node type'))
-	]
+    name = 'dhcp_netbiosFixedAttributes'
+    choices = [
+        ('univentionDhcpNetbiosNameServers', _('NetBIOS name servers')),
+        ('univentionDhcpNetbiosScope', _('NetBIOS scope')),
+        ('univentionDhcpNetbiosNodeType', _('NetBIOS node type')),
+    ]
 
 
 module = 'policies/dhcp_netbios'
@@ -74,56 +70,56 @@ object_name_plural = _('DHCP NetBIOS policies')
 policy_short_description = _('NetBIOS')
 long_description = ''
 options = {
-	'default': univention.admin.option(
-		short_description=short_description,
-		default=True,
-		objectClasses=['top', 'univentionPolicy', 'univentionPolicyDhcpNetbios'],
-	),
+    'default': univention.admin.option(
+        short_description=short_description,
+        default=True,
+        objectClasses=['top', 'univentionPolicy', 'univentionPolicyDhcpNetbios'],
+    ),
 }
 property_descriptions = {
-	'name': univention.admin.property(
-		short_description=_('Name'),
-		long_description='',
-		syntax=univention.admin.syntax.policyName,
-		include_in_default_search=True,
-		required=True,
-		may_change=False,
-		identifies=True,
-	),
-	'netbios_name_servers': univention.admin.property(
-		short_description=_('NetBIOS name servers'),
-		long_description=_('List of WINS servers listed in order of preference'),
-		syntax=univention.admin.syntax.string,
-		multivalue=True,
-	),
-	'netbios_scope': univention.admin.property(
-		short_description=_('NetBIOS scope'),
-		long_description=_('NetBIOS over TCP/IP scope parameter'),
-		syntax=univention.admin.syntax.string,
-	),
-	'netbios_node_type': univention.admin.property(
-		short_description=_('NetBIOS node type'),
-		long_description=_('The node type of clients for NetBIOS over TCP/IP'),
-		syntax=univention.admin.syntax.netbiosNodeType,
-	),
+    'name': univention.admin.property(
+        short_description=_('Name'),
+        long_description='',
+        syntax=univention.admin.syntax.policyName,
+        include_in_default_search=True,
+        required=True,
+        may_change=False,
+        identifies=True,
+    ),
+    'netbios_name_servers': univention.admin.property(
+        short_description=_('NetBIOS name servers'),
+        long_description=_('List of WINS servers listed in order of preference'),
+        syntax=univention.admin.syntax.string,
+        multivalue=True,
+    ),
+    'netbios_scope': univention.admin.property(
+        short_description=_('NetBIOS scope'),
+        long_description=_('NetBIOS over TCP/IP scope parameter'),
+        syntax=univention.admin.syntax.string,
+    ),
+    'netbios_node_type': univention.admin.property(
+        short_description=_('NetBIOS node type'),
+        long_description=_('The node type of clients for NetBIOS over TCP/IP'),
+        syntax=univention.admin.syntax.netbiosNodeType,
+    ),
 }
 property_descriptions.update(dict([
-	requiredObjectClassesProperty(),
-	prohibitedObjectClassesProperty(),
-	fixedAttributesProperty(syntax=dhcp_netbiosFixedAttributes),
-	emptyAttributesProperty(syntax=dhcp_netbiosFixedAttributes),
-	ldapFilterProperty(),
+    requiredObjectClassesProperty(),
+    prohibitedObjectClassesProperty(),
+    fixedAttributesProperty(syntax=dhcp_netbiosFixedAttributes),
+    emptyAttributesProperty(syntax=dhcp_netbiosFixedAttributes),
+    ldapFilterProperty(),
 ]))
 
 layout = [
-	Tab(_('Netbios'), _('SMB/CIFS name resolution'), layout=[
-		Group(_('General DHCP NetBIOS settings'), layout=[
-			'name',
-			'netbios_name_servers',
-			['netbios_scope', 'netbios_node_type'],
-		]),
-	]),
-	policy_object_tab()
+    Tab(_('Netbios'), _('SMB/CIFS name resolution'), layout=[
+        Group(_('General DHCP NetBIOS settings'), layout=[
+            'name',
+            'netbios_name_servers',
+            ['netbios_scope', 'netbios_node_type'],
+        ]),
+    ]),
+    policy_object_tab(),
 ]
 
 mapping = univention.admin.mapping.mapping()
@@ -135,7 +131,7 @@ register_policy_mapping(mapping)
 
 
 class object(univention.admin.handlers.simplePolicy):
-	module = module
+    module = module
 
 
 lookup = object.lookup
