@@ -30,16 +30,15 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"""
-|UDM| module for container settings
-"""
+"""|UDM| module for container settings"""
 
-from univention.admin.layout import Tab
-import univention.admin.uldap
-import univention.admin.syntax
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
+import univention.admin.syntax
+import univention.admin.uldap
+from univention.admin.layout import Tab
+
 
 translation = univention.admin.localization.translation('univention.admin.handlers.settings')
 _ = translation.translate
@@ -52,26 +51,26 @@ object_name = _('Univention Setting')
 object_name_plural = _('Univention Settings')
 long_description = ''
 options = {
-	'default': univention.admin.option(
-		short_description=short_description,
-		default=True,
-		objectClasses=['top', 'organizationalRole'],
-	),
+    'default': univention.admin.option(
+        short_description=short_description,
+        default=True,
+        objectClasses=['top', 'organizationalRole'],
+    ),
 }
 property_descriptions = {
-	'name': univention.admin.property(
-		short_description=_('Name'),
-		long_description='',
-		syntax=univention.admin.syntax.string,
-		include_in_default_search=True,
-		required=True,
-		may_change=False,
-		identifies=True,
-	),
+    'name': univention.admin.property(
+        short_description=_('Name'),
+        long_description='',
+        syntax=univention.admin.syntax.string,
+        include_in_default_search=True,
+        required=True,
+        may_change=False,
+        identifies=True,
+    ),
 }
 
 layout = [
-	Tab(_('General'), _('Basic values'), ["name"])
+    Tab(_('General'), _('Basic values'), ["name"]),
 ]
 
 mapping = univention.admin.mapping.mapping()
@@ -79,14 +78,14 @@ mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 
 
 class object(univention.admin.handlers.simpleLdap):
-	module = module
+    module = module
 
-	@classmethod
-	def unmapped_lookup_filter(cls):
-		return univention.admin.filter.conjunction('&', [
-			univention.admin.filter.expression('objectClass', 'organizationalRole'),
-			univention.admin.filter.expression('cn', 'univention')
-		])
+    @classmethod
+    def unmapped_lookup_filter(cls):
+        return univention.admin.filter.conjunction('&', [
+            univention.admin.filter.expression('objectClass', 'organizationalRole'),
+            univention.admin.filter.expression('cn', 'univention'),
+        ])
 
 
 lookup = object.lookup
@@ -94,4 +93,4 @@ lookup_filter = object.lookup_filter
 
 
 def identify(dn, attr, canonical=False):
-	return b'organizationalRole' in attr.get('objectClass', []) and attr.get('cn', []) == [b'univention']
+    return b'organizationalRole' in attr.get('objectClass', []) and attr.get('cn', []) == [b'univention']
